@@ -1,15 +1,14 @@
 from wagtail.admin.edit_handlers import StreamFieldPanel
 
-from ..amp.mixins import AmpMixin
-from ..bakery.models import BuildableWagtailBakeryModel
-from .. import constants
-
-from ...loader import get_model
+from webspace.cms.amp.mixins import AmpMixin
+from webspace.cms.bakery.abstract import WagtailPageBakeryModel
+from webspace.cms import constants
+from webspace.loader import get_model
 
 GenericPage = get_model('cms', 'GenericPage')
 
 
-class AContentPage(AmpMixin, BuildableWagtailBakeryModel, GenericPage):
+class AContentPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
     template = '%s/content_page.html' % constants.PAGES_TEMPLATES_PATH
 
     promote_panels = GenericPage.promote_panels + [
